Chicken Taco Salad with Chili Lime Chicken & Homemade Salad Dressing
Description: Chicken Taco Salad with Chili Lime Chicken is an easy summer salad recipe that is perfect for the main dish on a hot summer day! Fresh crispy romaine lettuce topped with Juicy chicken with an amazing chili rub, corn, black beans, tomatoes and homemade taco seasoning salad dressing.
Date: 2021-02-24T19:00:00+00:00

↑

- Skip to primary navigation
- Skip to main content
- Skip to primary sidebar
- Skip to footer

# Chicken Taco Salad with Chili Lime Chicken

As an Amazon Associate and affiliate with other networks, I may earn a commission from purchases made through links within this post. For more information read my disclosure page here.

Published by Lauren on February 24, 2021.

Share With Friends!

4823 shares

- Share68
- Tweet

Jump to Recipe
Print Recipe

Chicken Taco Salad with Chili Lime Chicken is an easy summer salad recipe that is perfect for the main dish on a hot summer day! Fresh crispy romaine lettuce topped with Juicy chicken with an amazing chili rub, corn, black beans, tomatoes and homemade taco seasoning salad dressing.

## Chicken Taco Salad

We love tacos, so this Skinny Chicken Taco Salad is a big hit in our house. My husband has been in a huge salad kick recently and I am not the type who can just eat a boring salad over and over again. I need to change it up and I need to feel full after eating my salad.

I love this Chicken Taco Salad with grilled chicken for this very reason, it is very filling with the chicken and the beans. Yet it has a light dressing made with Greek yogurt.

Looking for more tasty salad recipes? Check these out!

- Beef taco salad
- BLT Salad
- Strawberry Spinach Salad
- Crispy chicken, cranberry and apple salad

## What to Serve with Chicken Taco Salad

You can serve this southwest taco salad by itself as a meal or you can enjoy it as the main dish. There are lots of tasty side dishes that you can serve with this taco salad recipe.

- Mexican Rice
- Homemade Tortilla chips and Guacamole
- White Cheddar Queso
- Sheet pan Quesadillas
- Restaurant Style Salsa
- Taco Cups
- Cheese Quesadillas

## How to Bake Chicken

I normally use chili lime chicken when I make this easy chicken taco salad, but if you want to bake chicken you can and it is easy to do.

Place chicken breasts in a baking pan add a little olive oil and rub it on the bottom of the pan so the chicken does not stick. Then cook at 400 degrees for 30-40 minutes. You want the chicken to be at 165 degrees Fahrenheit.

## Tips for making this recipe

Use a Salad Spinner. Having a salad spinner makes it really easy to get your lettuce washed, I don’t know about you but I hate it when I get water all over the place when I am washing my lettuce. It drives me crazy, so a salad spinner saves me clean up time!

Serve cold or hot. This chicken taco salad recipe works well if the chicken, corn and beans are warm or chilled.

Make it Low Carb! If you are sticking to a low carb diet, skip the corn and black beans when making this salad.

Make it a meal or a side dish! If you would like to have this as a side dish you easily can or you can make it the main dish of a meal.

Use chicken you have on hand or chili lime chicken. I love making this Chicken Taco Salad with my chili lime chicken but if you are running short on time you can always use a rotisserie chicken or chicken breast you already have cooked.

## How to Make Taco Salad Dressing

Making taco salad dressing is easy. All you need is Taco sauce, greek yogurt and ranch dressing. Mix them all together in a bowl or a salad dressing shaker and you are done.

I personally like to keep the salad dressing in my fridge for whenever I want to use it because it is an amazing taco salad dressing.

It is easy to double/triple/10 times the salad dressing recipe and store it in the fridge. Then I use this salad dressing shaker for mixing the salad dressing in it and then storing it in the fridge. You can easily pour your dressing on your salad right from the salad dressing shaker.

## Chicken Taco Salad Ingredients

- Chicken
- Taco salad Dressing
- Romain Lettuce
- Grape tomatoes
- Canned black beans
- Black Olives
- Canned or fresh cooked corn
- Shredded Sharp Cheddar Cheese
- avocado

### Chicken Taco Salad Dressing ingredients

- Jarred Taco Sauce
- Ranch Dressing
- Plain Greek Yogurt

### Chicken Salad Taco Chicken & Chicken Rub Ingredients

- chicken breasts
- olive oil
- lime
- chili powder
- garlic powder
- brown sugar – if you are low carb or keto then use Golden Monkfruit
- chipotle chili powder
- ground cumin
- paprika
- onion powder
- salt
- black pepper

## How to Make Taco Salad with Chicken

Mix all spices, brown sugar, olive oil and lime together in a small bowl.

Slice your chicken breast into to thin slices so you end up with 4-6 thin but wide pieces of chicken breast.

Rub the chicken with the mixture and place in the fridge for at least 20 minutes.

Grill the chicken at 375 for 6 minutes on each side until the internal temperature reaches 160°.

Remove from the grill and let sit for 5 minutes before slicing.

While the chicken is sitting, prep your salad ingredients.

Wash and chop the romaine lettuce. And place into bowls or on plates.

In a small bowl mix taco sauce, greek yogurt and ranch dressing and set aside.

Was the tomatoes and dice them, and place on top of the lettuce.

Drain the olives and slice them and place on top of the salad.

Rinse the canned corn and heat in the microwave for 2 minutes. If using frozen bagged corn heat the corn according to the package and then put on top of the salad.

Rinse the black beans and pour into a bowl and heat in the microwave for 2 minutes and then put on top of the salad.

Shred and sprinkle the cheese on top of the salad.

Slice the chicken once fully rested and place on top of the salad.

Drizzle with the homemade taco salad dressing.

Love tacos? Check these out!

- Chicken Taco Lettuce Wraps
- Crockpot Taco Soup
- Homemade taco seasoning
- Crockpot taco meat
- Chaffle Taco shells
- Layered Taco Dip
- Crockpot chicken tacos
- Taco Pockets

## Chicken Taco Salad with Chili Lime Chicken

Chicken Taco Salad with Chili Lime Chicken is an easy summer salad recipe that is perfect for the main dish on a hot summer day! Fresh crispy romaine lettuce topped with Juicy chicken with an amazing chili rub, corn, black beans, tomatoes and homemade taco seasoning salad dressing.
2.56 from 9 votes
Print
Pin
Rate
Prep Time: 10 minutes
Cook Time: 45 minutes
Total Time: 55 minutes
Servings: 6 servings
Author Lauren
Cook Mode Prevent your screen from going dark

### Ingredients

#### Chicken Taco Salad ingredients

- 2 pounds chicken breasts
- Taco Salad dressing
- 2 cups grape tomatoes
- 3 cups romaine lettuce
- 1 cup shredded cheddar cheese
- 15 ounce can black beans
- 15 ounces corn canned or frozen
- 6 ounces canned black olives
- 1 hass avocado

#### Taco Salad Chicken Rub Ingredients

- 1 lime zest and the juice
- 1 teaspoon chili powder
- 1 teaspoon garlic powder
- 1 teaspoon brown sugar
- 1/2 teaspoon chili powder
- 1/2 teaspoon ground cumin
- 1/2 teaspoon paprika
- 1/2 teaspoon onion powder
- 3/4 teaspoon salt
- 1/4 teaspoon black pepper

#### Taco Salad Dressing ingredients

- 1/2 cup taco sauce
- 1/2 cup plain greek yogurt
- 1/2 cup ranch dressing

### Instructions

- Mix all spices, brown sugar, olive oil and lime together in a small bowl.
- Slice your chicken breast into to thin slices so you end up with 4-6 thin but wide pieces of chicken breast.
- Rub the chicken with the mixture and place in the fridge for at least 20 minutes.
- Grill the chicken at 375 for 6 minutes on each side until the internal temperature reaches 160°.
- Remove from the grill and let sit for 5 minutes before slicing.
- While the chicken is sitting, prep your salad ingredients.
- Wash and chop the romaine lettuce. And place into bowls or on plates.
- In a small bowl mix taco sauce, greek yogurt and ranch dressing and set aside.
- Was the tomatoes and dice them, and place on top of the lettuce.
- Drain the olives and slice them and place on top of the salad.
- Rinse the canned corn and heat in the microwave for 2 minutes. If using frozen bagged corn heat the corn according to the package and then put on top of the salad.
- Rinse the black beans and pour into a bowl and heat in the microwave for 2 minutes and then put on top of the salad.
- Peel and slice the avocado and place on top of the salad.
- Shred and sprinkle the cheese on top of the salad.
- Slice the chicken once fully rested and place on top of the salad.
- Drizzle with the homemade taco salad dressing.

### Nutrition

Calories: 643kcal | Carbohydrates: 49g | Protein: 47g | Fat: 31g | Saturated Fat: 8g | Cholesterol: 124mg | Sodium: 3129mg | Potassium: 1361mg | Fiber: 15g | Sugar: 11g | Vitamin A: 5121IU | Vitamin C: 32mg | Calcium: 230mg | Iron: 5mg
Course Dinner, Main Course, Salad
Cuisine American
Keyword Chicken Taco Salad, taco salad with chicken
Share on Facebook
Pin Recipe
Tried this recipe? Mention @midgetmomma or tag #MidgetMommaRecipes

Use low fat cheese and low fat dressing and this salad is 7 Weight Watchers FreeStyle Points!

### More Chicken Recipes you will love!

- Slow Cooker Parmesan Garlic Chicken Bake
- Rosemary Garlic Chicken Meatballs
- Slow Cooker Asian Chicken
- Dorito Chicken Casserole
- Chicken and Potato Casserole
- Cracker Barrel Chicken and Dumplings

### ABOUT LAUREN

Hey There! I am Lauren, a short mom (4 foot 10 to be exact!) who has a passion for helping others and always has a cup of coffee in hand. With amazing recipes to help the home cook become a home chef, along with fun family travel, fun crafts and More! Grab a cup of coffee and join me! Read more...

« Previous Post
Newer Post »

Share With Friends!

4823 shares

- Share68
- Tweet

#### About Stephanie

With a degree from the Culinary Institute of America in baking and pastry arts, a love for tasty food and amazing photography skills Stephanie brings the amazing recipe ideas we come up with to life. Stephanie loves crafting, all things Disney and traveling whenever possible.

#### Join the E-Club

Get recipes, crafts, travel tips, and more straight to your inbox!

There was an error submitting your subscription. Please try again.

## Reader Interactions

### Comments

1. Ashley Tobey says

   January 12, 2017 at 4:27 PM

   Hi!
   What’s 1/2 ranch dressing? Half a cup? Half a packet?

   Reply

   - Stephanie says

     January 16, 2017 at 9:23 AM

     1/2 of a cup of ranch dressing.

2. Alyssa says

   January 26, 2017 at 12:56 AM

   Is taco sauce the same as taco seasoning?

   Reply

   - Stephanie says

     January 30, 2017 at 1:29 PM

     No it is not it is a premade sauce you can find in the same spot as taco seasoning in the store.

3. Linda says

   February 27, 2017 at 1:59 PM

   Do you have the nutritional information for this salad?

   Reply

   - Stephanie says

     February 28, 2017 at 4:04 PM

     No, sorry I do not. If you would like you can always put these ingredients into a food calculator online.

### Leave a Reply Cancel reply

Your email address will not be published. Required fields are marked *

Comment

Name *

Email *

Website

Current [email protected] *
Leave this field empty

SEEN ON

Midget Momma is licensed under a Creative Commons Attribution-NonCommercial-ShareAlike 3.0 Unported License.
We use cookies to offer you a better browsing experience, analyze site traffic, personalize content, and serve targeted advertisements. If you continue to use this site, you consent to our use of cookies.Accept Read our Privacy & Cookie Policy
Cookies Policy

#### Privacy Overview

This website uses cookies to improve your experience while you navigate through the website. Out of these, the cookies that are categorized as necessary are stored on your browser as they are essential for the working of basic functionalities of the website. We also use third-party cookies that help us analyze and understand how you use this website. These cookies will be stored in your browser only with your consent. You also have the option to opt-out of these cookies. But opting out of some of these cookies may affect your browsing experience.
Necessary
Necessary
Always Enabled

Necessary cookies are absolutely essential for the website to function properly. This category only includes cookies that ensures basic functionalities and security features of the website. These cookies do not store any personal information.

Non-necessary
Non-necessary

Any cookies that may not be particularly necessary for the website to function and is used specifically to collect user personal data via analytics, ads, other embedded contents are termed as non-necessary cookies. It is mandatory to procure user consent prior to running these cookies on your website.